Apical.Plug.Router (apical v0.3.0)

Copy Markdown View Source

boilerplate code setting up a router using the Plug framework without using Phoenix. Note that although this reduces the needed dependencies, this doesn't provide you with some Phoenix affordances such as route helpers.

Summary

Functions

returns a 404 error since none of the routes have matched

Functions

match(conn, opts)

returns a 404 error since none of the routes have matched